==> grails-1.2.2.tbz: share/java/grails/src/java/org/codehaus/groovy/grails/web/taglib/GroovyGrepTag.java <==
/* Copyright 2004-2005 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.codehaus.groovy.grails.web.taglib;

import org.apache.commons.lang.StringUtils;
import org.codehaus.groovy.grails.web.taglib.exceptions.GrailsTagException;

/**
 *
 * Example:
 *
 * <code>
 *  <gr:grep in="${thing}" filter="${Pattern.compile('[a-zA-Z]')}">
 *        <p>${it}</p>
 *  </gr:grep>
 * </code>
 *
 * @author Graeme Rocher
 * @since 19-Jan-2006
 */
public class GroovyGrepTag extends GroovySyntaxTag{
   public static final String TAG_NAME = "grep";
    private static final String ATTRIBUTE_FILTER = "filter";

    public boolean isKeepPrecedingWhiteSpace() {
        return false;
    }

    public boolean isAllowPrecedingContent() {
        return true;
    }

    public void doStartTag() {
        String in = (String) attributes.get(ATTRIBUTE_IN);
        String filter = (String) attributes.get(ATTRIBUTE_FILTER);
        if(StringUtils.isBlank(in))
            throw new GrailsTagException("Tag ["+TAG_NAME+"] missing required attribute ["+ATTRIBUTE_IN+"]");
        if(StringUtils.isBlank(filter))
            throw new GrailsTagException("Tag ["+TAG_NAME+"] missing required attribute ["+ATTRIBUTE_FILTER +"]");

        StringBuilder builder = new StringBuilder();
        builder.append(in);
        builder.append(".grep(");
        filter = calculateExpression(filter);
        builder.append(filter);
        builder.append(")");
        doEachMethod(builder.toString());
    }

    public void doEndTag() {
        out.println("}");
    }

    public String getName() {
        return TAG_NAME;
    }
}

==> grails-1.3.3.tbz: share/java/grails/src/java/org/codehaus/groovy/grails/web/taglib/GroovyGrepTag.java <==
/* Copyright 2004-2005 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.codehaus.groovy.grails.web.taglib;

import org.apache.commons.lang.StringUtils;
import org.codehaus.groovy.grails.web.taglib.exceptions.GrailsTagException;

/**
 *
 * Example:
 *
 * <code>
 *  <gr:grep in="${thing}" filter="${Pattern.compile('[a-zA-Z]')}">
 *        <p>${it}</p>
 *  </gr:grep>
 * </code>
 *
 * @author Graeme Rocher
 */
public class GroovyGrepTag extends GroovySyntaxTag {

    public static final String TAG_NAME = "grep";
    private static final String ATTRIBUTE_FILTER = "filter";

    @Override
    public boolean isKeepPrecedingWhiteSpace() {
        return false;
    }

    @Override
    public boolean isAllowPrecedingContent() {
        return true;
    }

    public void doStartTag() {
        String in = attributes.get(ATTRIBUTE_IN);
        if (StringUtils.isBlank(in)) {
            throw new GrailsTagException("Tag [" + TAG_NAME + "] missing required attribute [" + ATTRIBUTE_IN + "]");
        }

        String filter = attributes.get(ATTRIBUTE_FILTER);
        if (StringUtils.isBlank(filter)) {
            throw new GrailsTagException("Tag [" + TAG_NAME + "] missing required attribute [" + ATTRIBUTE_FILTER + "]");
        }

        StringBuilder builder = new StringBuilder();
        builder.append(in);
        builder.append(".grep(");
        filter = calculateExpression(filter);
        builder.append(filter);
        builder.append(")");
        doEachMethod(builder.toString());
    }

    public void doEndTag() {
        out.println("}");
    }

    public String getName() {
        return TAG_NAME;
    }
}
